@@ -1,6 +1,5 @@
-from office365.sharepoint.caml.utils import to_camel
-
 from sharepoint_rest_api.libs.search_request import SearchRequest
+from sharepoint_rest_api.utils import to_camel
 
 
 class SearchRequestBuilder:
@@ -18,7 +17,7 @@ class SearchRequestBuilder:
         'contains': '*'
     }
 
-    def __init__(self, filters, select):
+    def __init__(self, filters=None, select=None):
         self.filters = filters
         self.select = select
 
